netapp_ontap.models.zapp_nvme_components_subsystem API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.zapp_nvme_components_subsystem`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class ZappNvmeComponentsSubsystemSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the ZappNvmeComponentsSubsystem object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `hosts: List[ZappNvmeComponentsSubsystemHosts] GET POST PATCH`

    The hosts field of the zapp_nvme_components_subsystem.

  `name: str GET POST PATCH`

    The name of the subsystem accessing the component. If neither the name nor the UUID is provided, the name defaults to <application-name>_<component-name>, whether that subsystem already exists or not.

  `os_type: str GET POST PATCH`

    The name of the host OS accessing the component. The default value is the host OS that is running the application.

    Valid choices:

    - aix
    - linux
    - vmware
    - windows
  `uuid: str GET POST PATCH`

    The UUID of an existing subsystem to be granted access to the component.